@@ -33,17 +33,12 @@ def _create_model_card(repo_dir: Path):
 
 def _copy_file(filepath: Path, dst_directory: Path):
     """
-    Copy the model.zip file to the correct directory
-    :param filepath: path of the model.zip file
+    Copy the file to the correct directory
+    :param filepath: path of the file
     :param dst_directory: destination directory
     """
-    # We check if filename has zip extension indicated or not
-    if filepath.name.endswith('.zip') is False and filepath.name.endswith('.mp4') is False:
-        filename = filepath.name + ".zip"
-    else:
-        filename = filepath.name
-    dst = dst_directory / filename
-    shutil.copy(str(filename), str(dst))
+    dst = dst_directory / filepath.name
+    shutil.copy(str(filepath.name), str(dst))
 
 
 def push_to_hub(repo_id: str,
@@ -94,6 +89,7 @@ def push_to_hub(repo_id: str,
 
     # Todo: I need to have a feedback like:
     # You can see your model here "https://huggingface.co/repo_url"
+    print("Your model has been uploaded to the Hub, you can find it here: ", repo_url)
     return repo_url
 
 
